@@ -112,8 +112,7 @@ SENSORS_INSMOD_2(adm1025, ne1619);
 
 #define ALARMS_FROM_REG(val) (val)
 
-/* For each registered ADM1025, we need to keep some data in memory. That
-   data is pointed to by adm1025_list[NR]->data. The structure itself is
+/* For each registered ADM1025, we need to keep some data in memory. It is
    dynamically allocated, at the same time when a new adm1025 client is
    allocated. */
 struct adm1025_data {
@@ -156,8 +155,6 @@ static void adm1025_vid(struct i2c_client *client, int operation,
 static void adm1025_vrm(struct i2c_client *client, int operation,
 			int ctl_name, int *nrels_mag, long *results);
 
-static int adm1025_id = 0;
-
 static struct i2c_driver adm1025_driver = {
 	.name		= "ADM1025 sensor driver",
 	.id		= I2C_DRIVERID_ADM1025,
@@ -176,7 +173,7 @@ static struct i2c_driver adm1025_driver = {
 #define ADM1025_SYSCTL_IN4     1004
 #define ADM1025_SYSCTL_IN5     1005
 
-#define ADM1025_SYSCTL_RTEMP   1250 /* Degrees Celcius * 10 */
+#define ADM1025_SYSCTL_RTEMP   1250 /* Degrees Celsius * 10 */
 #define ADM1025_SYSCTL_TEMP    1251
 
 #define ADM1025_SYSCTL_ALARMS  2001 /* bitvector */
@@ -314,7 +311,7 @@ static int adm1025_detect(struct i2c_adapter *adapter, int address,
 		client_name = "NE1619 chip";		
 	} else {
 #ifdef DEBUG
-		printk("adm1025.o: Internal error: unknown kind (%d)?!?",
+		printk("adm1025.o: Internal error: unknown kind (%d)\n",
 		       kind);
 #endif
 		goto ERROR1;
@@ -323,8 +320,6 @@ static int adm1025_detect(struct i2c_adapter *adapter, int address,
 	/* Fill in the remaining client fields and put it into the global list */
 	strcpy(new_client->name, client_name);
 	data->type = kind;
-
-	new_client->id = adm1025_id++;
 	data->valid = 0;
 	init_MUTEX(&data->update_lock);
 
