@@ -68,7 +68,7 @@ void print_long_help(void)
   printf("Usage: %s [OPTION]... [CHIP]...\n",PROGRAM);
   printf("  -c, --config-file     Specify a config file (default: " ETCDIR "/" DEFAULT_CONFIG_FILE_NAME ")\n");
   printf("  -h, --help            Display this help text\n");
-  printf("  -s, --set             Execute `set' statements too (root only)\n");
+  printf("  -s, --set             Execute `set' statements (root only)\n");
   printf("  -f, --fahrenheit      Show temperatures in degrees fahrenheit\n");
   printf("  -A, --no-adapter      Do not show adapter for each chip\n");
   printf("  -U, --no-unknown      Do not show unknown chips\n");
@@ -94,7 +94,7 @@ void print_version(void)
 
 /* This examines global var config_file, and leaves the name there too. 
    It also opens config_file. */
-void open_config_file(const char* config_file_name)
+static void open_config_file(const char* config_file_name)
 {
   if (!strcmp(config_file_name,"-")) {
     config_file = stdin;
@@ -109,7 +109,7 @@ void open_config_file(const char* config_file_name)
   }
 }
     
-void close_config_file(const char* config_file_name)
+static void close_config_file(const char* config_file_name)
 {
   if (fclose(config_file) == EOF) {
     fprintf(stderr,"Could not close config file\n");
@@ -229,16 +229,18 @@ int main (int argc, char *argv[])
       }
 
   open_config_file(config_file_name);
-  if ((res = sensors_init(config_file))) {
+  res = sensors_init(config_file);
+  close_config_file(config_file_name);
+  if (res) {
     fprintf(stderr,"%s\n",sensors_strerror(res));
     if (res == -SENSORS_ERR_PROC)
       fprintf(stderr,
               "Kernel interface access error\n"
               "For 2.6 kernels, make sure you have mounted sysfs and libsensors\n"
               "was compiled with sysfs support!\n");
+    sensors_cleanup();
     exit(1);
   }
-  close_config_file(config_file_name);
 
   /* build the degrees string */
   set_degstr();
@@ -247,7 +249,7 @@ int main (int argc, char *argv[])
     sensors_cleanup();
     exit(error);
   } else {
-    if(chips[0].prefix == SENSORS_CHIP_NAME_PREFIX_ANY)
+    if (optind == argc) /* No chip name on command line */
 	    fprintf(stderr,
 	            "No sensors found!\n"
 	            "Make sure you loaded all the kernel drivers you need.\n"
@@ -324,7 +326,7 @@ struct match {
 	void (*fn) (const sensors_chip_name *name);
 };
 
-struct match matches[] = {
+static struct match matches[] = {
 	{ "ds1621", print_ds1621 },
 	{ "lm75", print_lm75 },
 	{ "adm1021", print_adm1021 },
@@ -360,7 +362,7 @@ struct match matches[] = {
 	{ "adm1024", print_adm1024 },
 	{ "w83781d", print_w83781d },
 	{ "w83782d", print_w83781d },
-	{ "w83783d", print_w83781d },
+	{ "w83783s", print_w83781d },
 	{ "w83627hf", print_w83781d },
 	{ "w83627thf", print_w83781d },
 	{ "w83637hf", print_w83781d },
@@ -382,8 +384,6 @@ struct match matches[] = {
 	{ "it8712", print_it87 },
 	{ "it8716", print_it87 },
 	{ "it8718", print_it87 },
-	{ "ddcmon", print_ddcmon },
-	{ "eeprom", print_eeprom },
 	{ "fscpos", print_fscpos },
 	{ "fscscy", print_fscscy },
 	{ "fscher", print_fscher },
@@ -409,6 +409,7 @@ struct match matches[] = {
 	{ "lm86", print_lm90 },
 	{ "max6657", print_lm90 },
 	{ "adt7461", print_lm90 },
+	{ "max6680", print_lm90 },
 	{ "lm63", print_lm63 },
 	{ "xeontemp", print_xeontemp },
 	{ "max6650", print_max6650 },
@@ -421,8 +422,17 @@ struct match matches[] = {
 	{ "f71805f", print_f71805f },
 	{ "f71872f", print_f71805f },
  	{ "abituguru", print_abituguru },
+ 	{ "abituguru3", print_abituguru3 },
  	{ "k8temp", print_k8temp },
  	{ "coretemp", print_coretemp },
+ 	{ "dme1737", print_dme1737 },
+ 	{ "sch311x", print_dme1737 },
+	{ "applesmc", print_applesmc },
+	{ "f71882fg", print_f71882fg },
+	{ "thmc50", print_thmc50 },
+	{ "adm1022", print_thmc50 },
+	{ "fschmd", print_fschmd },
+	{ "fschrc", print_fschmd },
 	{ NULL, NULL }
 };
 
@@ -438,6 +448,11 @@ void do_a_print(sensors_chip_name name)
   if(m->prefix==NULL && hide_unknown)
     return;
 
+  /* Explicitly reject eeprom and ddcmon, we no longer support them
+     but libsensors may */
+  if (!strcmp(name.prefix, "eeprom") || !strcmp(name.prefix, "ddcmon"))
+    return;
+
   printf("%s\n",sprintf_chip_name(name));
   if (!hide_adapter) {
     const char *adap = sensors_get_adapter_name(name.bus);
